Module apl

Module apl 

2.3 Application framework 2.3 The ZigBee Application Framework

The application framework in ZigBee is the environment in which application objects are hosted on ZigBee devices.

Modules

descriptors
2.3.2 ZigBee Descriptors ZigBee devices describe themselves using descriptor data structures. The actual data contained in these descriptors is defined in the individual device descriptions. There are five descriptors: node, node power, simple, complex, and user.